==> nextcloud-29.0.8.tgz: nextcloud/apps/twofactor_totp/l10n/sv.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Du aktiverade TOTP tvåstegsverifiering för ditt konto",
    "You disabled TOTP two-factor authentication for your account" : "Du avaktiverade TOTP tvåstegsverifiering för ditt konto",
    "TOTP two-factor authentication disabled by an admin" : "TOTP två-faktor autentisering inaktiverad av en admin",
    "TOTP (Authenticator app)" : "TOTP (Autentiseringsapplikation)",
    "Authenticate with a TOTP app" : "Autentisera med en TOTP-app",
    "Two-Factor TOTP Provider" : "Tvåfaktor TOTP-leverantör",
    "TOTP two-factor provider" : "TOTP-leverantör av tvåfaktorsautentisering",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "En leverantör av tvåfaktorsautentisering för TOTP (RFC 6238)",
    "Enable TOTP" : "Aktivera TOTP",
    "Could not enable TOTP" : "Kunde inte aktivera TOTP",
    "Could not verify your key. Please try again" : "Kunde ej verifiera din nyckel. Vänligen försök igen",
    "Your new TOTP secret is:" : "Din nya TOTP-hemlighet är:",
    "For quick setup, scan this QR code with your TOTP app:" : "För snabb installation, skanna den här QR-koden med din TOTP-app:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "När du har konfigurerat din app, ange en testkod nedan för att säkerställa att det fungerar:",
    "Authentication code" : "Autentiseringskod",
    "Verify" : "Verifiera",
    "Get the authentication code from the two-factor authentication app on your device." : "Skriv in autentiseringskoden från tvåfaktorsautentiseringsappen på din enhet.",
    "Submit" : "Skicka"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/sv.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Du aktiverade TOTP tvåstegsverifiering för ditt konto",
    "You disabled TOTP two-factor authentication for your account" : "Du avaktiverade TOTP tvåstegsverifiering för ditt konto",
    "TOTP two-factor authentication disabled by the administration" : "TOTP två-faktor autentisering inaktiverad av administratören",
    "TOTP (Authenticator app)" : "TOTP (Autentiseringsapplikation)",
    "Authenticate with a TOTP app" : "Autentisera med en TOTP-app",
    "Two-Factor TOTP Provider" : "Tvåfaktor TOTP-leverantör",
    "Two-factor TOTP provider" : "Två-faktor TOTP-leverantör",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "En leverantör av två-faktorsautentisering för TOTP (RFC 6238)",
    "Enable TOTP" : "Aktivera TOTP",
    "Could not enable TOTP" : "Kunde inte aktivera TOTP",
    "Could not verify your key. Please try again" : "Kunde ej verifiera din nyckel. Vänligen försök igen",
    "Your new TOTP secret is:" : "Din nya TOTP-hemlighet är:",
    "For quick setup, scan this QR code with your TOTP app:" : "För snabb installation, skanna den här QR-koden med din TOTP-app:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "När du har konfigurerat din app, ange en testkod nedan för att säkerställa att det fungerar:",
    "Authentication code" : "Autentiseringskod",
    "Verify" : "Verifiera",
    "Get the authentication code from the two-factor authentication app on your device." : "Skriv in autentiseringskoden från tvåfaktorsautentiseringsappen på din enhet.",
    "Submit" : "Skicka",
    "TOTP two-factor authentication disabled by an admin" : "TOTP två-faktor autentisering inaktiverad av en admin",
    "TOTP two-factor provider" : "TOTP-leverantör av tvåfaktorsautentisering",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "En leverantör av tvåfaktorsautentisering för TOTP (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
